==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/authorization/kotlin/VariableAtManagementGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.authorization.kotlin

import com.pulumi.azurenative.authorization.kotlin.outputs.PolicyVariableColumnResponse
import com.pulumi.azurenative.authorization.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.authorization.kotlin.outputs.PolicyVariableColumnResponse.Companion.toKotlin as policyVariableColumnResponseToKotlin
import com.pulumi.azurenative.authorization.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [VariableAtManagementGroup].
 */
@PulumiTagMarker
public class VariableAtManagementGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: VariableAtManagementGroupArgs = VariableAtManagementGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend VariableAtManagementGroupArgsBuilder.() -> Unit) {
        val builder = VariableAtManagementGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): VariableAtManagementGroup {
        val builtJavaResource =
            com.pulumi.azurenative.authorization.VariableAtManagementGroup(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return VariableAtManagementGroup(builtJavaResource)
    }
}

/**
 * The variable.
 * Azure REST API version: 2022-08-01-preview.
 * ## Example Usage
 * ### Create or update a variable at management group
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var variableAtManagementGroup = new AzureNative.Authorization.VariableAtManagementGroup("variableAtManagementGroup", new()
 *     {
 *         Columns = new[]
 *         {
 *             new AzureNative.Authorization.Inputs.PolicyVariableColumnArgs
 *             {
 *                 ColumnName = "TestColumn",
 *             },
 *         },
 *         ManagementGroupId = "DevOrg",
 *         VariableName = "DemoTestVariable",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/authorization/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := authorization.NewVariableAtManagementGroup(ctx, "variableAtManagementGroup", &authorization.VariableAtManagementGroupArgs{
 * 			Columns: []authorization.PolicyVariableColumnArgs{
 * 				{
 * 					ColumnName: pulumi.String("TestColumn"),
 * 				},
 * 			},
 * 			ManagementGroupId: pulumi.String("DevOrg"),
 * 			VariableName:      pulumi.String("DemoTestVariable"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.authorization.VariableAtManagementGroup;
 * import com.pulumi.azurenative.authorization.VariableAtManagementGroupArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var variableAtManagementGroup = new VariableAtManagementGroup("variableAtManagementGroup", VariableAtManagementGroupArgs.builder()
 *             .columns(Map.of("columnName", "TestColumn"))
 *             .managementGroupId("DevOrg")
 *             .variableName("DemoTestVariable")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:authorization:VariableAtManagementGroup DemoTestVariable /providers/Microsoft.Management/managementGroups/{managementGroupId}/providers/Microsoft.Authorization/variables/{variableName}
 * ```
 */
public class VariableAtManagementGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.authorization.VariableAtManagementGroup,
) : KotlinCustomResource(javaResource, VariableAtManagementGroupMapper) {
    /**
     * Variable column definitions.
     */
    public val columns: Output<List<PolicyVariableColumnResponse>>
        get() = javaResource.columns().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    policyVariableColumnResponseToKotlin(args0)
                })
            })
        })

    /**
     * The name of the variable.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource (Microsoft.Authorization/variables).
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object VariableAtManagementGroupMapper : ResourceMapper<VariableAtManagementGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.authorization.VariableAtManagementGroup::class == javaResource::class

    override fun map(javaResource: Resource): VariableAtManagementGroup =
        VariableAtManagementGroup(
            javaResource as
                com.pulumi.azurenative.authorization.VariableAtManagementGroup,
        )
}

/**
 * @see [VariableAtManagementGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [VariableAtManagementGroup].
 */
public suspend fun variableAtManagementGroup(
    name: String,
    block: suspend VariableAtManagementGroupResourceBuilder.() -> Unit,
): VariableAtManagementGroup {
    val builder = VariableAtManagementGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [VariableAtManagementGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun variableAtManagementGroup(name: String): VariableAtManagementGroup {
    val builder = VariableAtManagementGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/authorization/kotlin/VariableAtManagementGroup.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.authorization.kotlin

import com.pulumi.azurenative.authorization.kotlin.outputs.PolicyVariableColumnResponse
import com.pulumi.azurenative.authorization.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import com.pulumi.azurenative.authorization.kotlin.outputs.PolicyVariableColumnResponse.Companion.toKotlin as policyVariableColumnResponseToKotlin
import com.pulumi.azurenative.authorization.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [VariableAtManagementGroup].
 */
@PulumiTagMarker
public class VariableAtManagementGroupResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: VariableAtManagementGroupArgs = VariableAtManagementGroupArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend VariableAtManagementGroupArgsBuilder.() -> Unit) {
        val builder = VariableAtManagementGroupArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): VariableAtManagementGroup {
        val builtJavaResource =
            com.pulumi.azurenative.authorization.VariableAtManagementGroup(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return VariableAtManagementGroup(builtJavaResource)
    }
}

/**
 * The variable.
 * Azure REST API version: 2022-08-01-preview.
 * ## Example Usage
 * ### Create or update a variable at management group
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var variableAtManagementGroup = new AzureNative.Authorization.VariableAtManagementGroup("variableAtManagementGroup", new()
 *     {
 *         Columns = new[]
 *         {
 *             new AzureNative.Authorization.Inputs.PolicyVariableColumnArgs
 *             {
 *                 ColumnName = "TestColumn",
 *             },
 *         },
 *         ManagementGroupId = "DevOrg",
 *         VariableName = "DemoTestVariable",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/authorization/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := authorization.NewVariableAtManagementGroup(ctx, "variableAtManagementGroup", &authorization.VariableAtManagementGroupArgs{
 * 			Columns: authorization.PolicyVariableColumnArray{
 * 				&authorization.PolicyVariableColumnArgs{
 * 					ColumnName: pulumi.String("TestColumn"),
 * 				},
 * 			},
 * 			ManagementGroupId: pulumi.String("DevOrg"),
 * 			VariableName:      pulumi.String("DemoTestVariable"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.authorization.VariableAtManagementGroup;
 * import com.pulumi.azurenative.authorization.VariableAtManagementGroupArgs;
 * import com.pulumi.azurenative.authorization.inputs.PolicyVariableColumnArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var variableAtManagementGroup = new VariableAtManagementGroup("variableAtManagementGroup", VariableAtManagementGroupArgs.builder()
 *             .columns(PolicyVariableColumnArgs.builder()
 *                 .columnName("TestColumn")
 *                 .build())
 *             .managementGroupId("DevOrg")
 *             .variableName("DemoTestVariable")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:authorization:VariableAtManagementGroup DemoTestVariable /providers/Microsoft.Management/managementGroups/{managementGroupId}/providers/Microsoft.Authorization/variables/{variableName}
 * ```
 */
public class VariableAtManagementGroup internal constructor(
    override val javaResource: com.pulumi.azurenative.authorization.VariableAtManagementGroup,
) : KotlinCustomResource(javaResource, VariableAtManagementGroupMapper) {
    /**
     * Variable column definitions.
     */
    public val columns: Output<List<PolicyVariableColumnResponse>>
        get() = javaResource.columns().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    policyVariableColumnResponseToKotlin(args0)
                })
            })
        })

    /**
     * The name of the variable.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource (Microsoft.Authorization/variables).
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object VariableAtManagementGroupMapper : ResourceMapper<VariableAtManagementGroup> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.authorization.VariableAtManagementGroup::class == javaResource::class

    override fun map(javaResource: Resource): VariableAtManagementGroup =
        VariableAtManagementGroup(
            javaResource as
                com.pulumi.azurenative.authorization.VariableAtManagementGroup,
        )
}

/**
 * @see [VariableAtManagementGroup].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [VariableAtManagementGroup].
 */
public suspend fun variableAtManagementGroup(
    name: String,
    block: suspend VariableAtManagementGroupResourceBuilder.() -> Unit,
): VariableAtManagementGroup {
    val builder = VariableAtManagementGroupResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [VariableAtManagementGroup].
 * @param name The _unique_ name of the resulting resource.
 */
public fun variableAtManagementGroup(name: String): VariableAtManagementGroup {
    val builder = VariableAtManagementGroupResourceBuilder()
    builder.name(name)
    return builder.build()
}
